@@ -1128,7 +1128,9 @@ class OMFITmhdin(OMFITnamelist):
     def from_miller(self, a=1.2, R=3.0, kappa=1.8, delta=0.4, zeta=0.0, zmag=0.0, nf=14, wf=0.05, hf=0.05, turns=100):
 
         self = self.init_mhdin('device')
-        Rf, Zf = rz_miller(a=a, R=R, kappa=kappa, delta=delta, zeta=zeta, zmag=zmag, poloidal_resolution=nf)
+        Rf, Zf = rz_miller(a=a, R=R, kappa=kappa, delta=delta, zeta=zeta, zmag=zmag, poloidal_resolution=nf + 2)
+        Rf = Rf[1:-1]
+        Zf = Zf[1:-1]
 
         # Conservatively set grid to include f-coils (bad idea for tokamak with blanket)
         self['IN3']['RLEFT'] = np.min(Rf) - 0.5 * wf
