@@ -1157,6 +1157,9 @@ SERVER = _SERVER()
 _is_server = utils_base.is_server
 
 
+SERVER_cache = {}
+
+
 def is_server(serverA, serverB):
     """
     Checks if `serverA` and `serverB` are the same server
@@ -1168,6 +1171,10 @@ def is_server(serverA, serverB):
     :return: serverB that matches serverA, otherwise False
     """
 
+    cache_id = (str(serverA), str(serverB))
+    if cache_id in SERVER_cache:
+        return SERVER_cache[cache_id]
+
     # generate list of all possible aliases for server A
     serverA_ = tolist(evalExpr(serverA))
     for serverA in serverA_:
@@ -1209,8 +1216,10 @@ def is_server(serverA, serverB):
                 if not tmp and is_localhost(serverA) and is_localhost(serverB):
                     tmp = True
                 if tmp:
+                    SERVER_cache[cache_id] = serverBname
                     return serverBname  # return original server B name as typed by user
 
+    SERVER_cache[cache_id] = False
     return False
 
 
@@ -1288,7 +1297,7 @@ def boto_credentials():
 print('-' * 20)
 print(' '.join(platform.uname()))
 print(repo_str)
-print('Python executable'.ljust(22) + ': ' + sys.executable)
+print('Python executable'.ljust(22) + ': ' + os.path.realpath(sys.executable))
 print('Installation type'.ljust(22) + ': ' + ['PERSONAL', 'PUBLIC'][os.path.exists(os.sep.join([OMFITsrc, '..', 'public']))])
 _OMFIT_important_directories = [
     'OMFITstartDir',
